/*
 *  jDTAUS Core RI Client Container
 *  Copyright (c) 2005 Christian Schulte (cs@jdtaus.org)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
package org.jdtaus.core.container.ri.client;

import java.util.Locale;
import java.util.ResourceBundle;
import java.text.MessageFormat;

class BootstrapEntityResolverBundle
{

  /** Singleton instance. */
  private static final BootstrapEntityResolverBundle instance =
    new BootstrapEntityResolverBundle();

  /** Creates a new {@code BootstrapEntityResolverBundle} instance. */
  BootstrapEntityResolverBundle()
  {
    this.getMessage ( "unsupportedSystemIdUri", Locale.getDefault() );
    this.getMessage ( "resolvedSystemIdUri", Locale.getDefault() );
  }

  /**
   * Gets the {@code BootstrapEntityResolverBundle} singleton.
   *
   * @return the {@code BootstrapEntityResolverBundle} singleton.
   */
  static BootstrapEntityResolverBundle getInstance()
  {
    return instance;
  }

  /**
   * Gets the text of the message with key {@code "unsupportedSystemIdUri"}.
   *
   * @return <pre>
   * Unsupported system id URI "{0}". {1}</pre>
   */
  String getUnsupportedSystemIdUriText ( final Locale locale )
  {
    return this.getMessage ( "unsupportedSystemIdUri", locale );
  }

  /**
   * Gets the message with key {@code "unsupportedSystemIdUri"}.
   *
   * @return <pre>
   * Unsupported system id URI "{0}". {1}</pre>
   */
  MessageFormat getUnsupportedSystemIdUriMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "unsupportedSystemIdUri", locale ), locale );
  }
  /**
   * Gets the text of the message with key {@code "resolvedSystemIdUri"}.
   *
   * @return <pre>
   * {0}
    -> {1}</pre>
   */
  String getResolvedSystemIdUriText ( final Locale locale )
  {
    return this.getMessage ( "resolvedSystemIdUri", locale );
  }

  /**
   * Gets the message with key {@code "resolvedSystemIdUri"}.
   *
   * @return <pre>
   * {0}
    -> {1}</pre>
   */
  MessageFormat getResolvedSystemIdUriMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "resolvedSystemIdUri", locale ), locale );
  }

  /**
   * Gets a message for a given key and locale.
   *
   * @param key the key of the message to return.
   * @param locale the locale of the message.
   *
   * @return message for {@code key} using {@code locale}.
   */
  private String getMessage( final String key, Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return ResourceBundle.getBundle( "org/jdtaus/core/container/ri/client/BootstrapEntityResolver",
                                     locale ).getString( key );

  }
}
