/*
 *  jDTAUS Core RI Client Container
 *  Copyright (c) 2005 Christian Schulte (cs@jdtaus.org)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
package org.jdtaus.core.container.ri.client;

import java.util.Locale;
import java.util.ResourceBundle;
import java.text.MessageFormat;

class DefaultModelBundle
{

  /** Singleton instance. */
  private static final DefaultModelBundle instance =
    new DefaultModelBundle();

  /** Creates a new {@code DefaultModelBundle} instance. */
  DefaultModelBundle()
  {
    this.getMessage ( "missingImplementation", Locale.getDefault() );
    this.getMessage ( "noPlatformSpecification", Locale.getDefault() );
    this.getMessage ( "unsupportedModelversion", Locale.getDefault() );
    this.getMessage ( "unresolvedImplementation", Locale.getDefault() );
    this.getMessage ( "platformModuleDescription", Locale.getDefault() );
    this.getMessage ( "deprecatedModel", Locale.getDefault() );
    this.getMessage ( "missingClassloaderError", Locale.getDefault() );
    this.getMessage ( "invalidMultiplicity", Locale.getDefault() );
    this.getMessage ( "noValidationWarning", Locale.getDefault() );
    this.getMessage ( "noInterface", Locale.getDefault() );
    this.getMessage ( "addedPlatformSpecification", Locale.getDefault() );
    this.getMessage ( "addedPlatformModule", Locale.getDefault() );
    this.getMessage ( "unsupportedMultiplicity", Locale.getDefault() );
    this.getMessage ( "unsupportedPropertyType", Locale.getDefault() );
  }

  /**
   * Gets the {@code DefaultModelBundle} singleton.
   *
   * @return the {@code DefaultModelBundle} singleton.
   */
  static DefaultModelBundle getInstance()
  {
    return instance;
  }

  /**
   * Gets the text of the message with key {@code "missingImplementation"}.
   *
   * @return <pre>
   * ({0}: {1})</pre>
   */
  String getMissingImplementationText ( final Locale locale )
  {
    return this.getMessage ( "missingImplementation", locale );
  }

  /**
   * Gets the message with key {@code "missingImplementation"}.
   *
   * @return <pre>
   * ({0}: {1})</pre>
   */
  MessageFormat getMissingImplementationMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "missingImplementation", locale ), locale );
  }
  /**
   * Gets the text of the message with key {@code "noPlatformSpecification"}.
   *
   * @return <pre>
   * {0} is no platform specification.</pre>
   */
  String getNoPlatformSpecificationText ( final Locale locale )
  {
    return this.getMessage ( "noPlatformSpecification", locale );
  }

  /**
   * Gets the message with key {@code "noPlatformSpecification"}.
   *
   * @return <pre>
   * {0} is no platform specification.</pre>
   */
  MessageFormat getNoPlatformSpecificationMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "noPlatformSpecification", locale ), locale );
  }
  /**
   * Gets the text of the message with key {@code "unsupportedModelversion"}.
   *
   * @return <pre>
   * Unsupported model version {0}.</pre>
   */
  String getUnsupportedModelversionText ( final Locale locale )
  {
    return this.getMessage ( "unsupportedModelversion", locale );
  }

  /**
   * Gets the message with key {@code "unsupportedModelversion"}.
   *
   * @return <pre>
   * Unsupported model version {0}.</pre>
   */
  MessageFormat getUnsupportedModelversionMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "unsupportedModelversion", locale ), locale );
  }
  /**
   * Gets the text of the message with key {@code "unresolvedImplementation"}.
   *
   * @return <pre>
   * No implementation available.</pre>
   */
  String getUnresolvedImplementationText ( final Locale locale )
  {
    return this.getMessage ( "unresolvedImplementation", locale );
  }

  /**
   * Gets the message with key {@code "unresolvedImplementation"}.
   *
   * @return <pre>
   * No implementation available.</pre>
   */
  MessageFormat getUnresolvedImplementationMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "unresolvedImplementation", locale ), locale );
  }
  /**
   * Gets the text of the message with key {@code "platformModuleDescription"}.
   *
   * @return <pre>
   * {1} Java Platform {0}.</pre>
   */
  String getPlatformModuleDescriptionText ( final Locale locale )
  {
    return this.getMessage ( "platformModuleDescription", locale );
  }

  /**
   * Gets the message with key {@code "platformModuleDescription"}.
   *
   * @return <pre>
   * {1} Java Platform {0}.</pre>
   */
  MessageFormat getPlatformModuleDescriptionMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "platformModuleDescription", locale ), locale );
  }
  /**
   * Gets the text of the message with key {@code "deprecatedModel"}.
   *
   * @return <pre>
   * The "{0}" module uses a deprecated model version. Please check for an updated version.</pre>
   */
  String getDeprecatedModelText ( final Locale locale )
  {
    return this.getMessage ( "deprecatedModel", locale );
  }

  /**
   * Gets the message with key {@code "deprecatedModel"}.
   *
   * @return <pre>
   * The "{0}" module uses a deprecated model version. Please check for an updated version.</pre>
   */
  MessageFormat getDeprecatedModelMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "deprecatedModel", locale ), locale );
  }
  /**
   * Gets the text of the message with key {@code "missingClassloaderError"}.
   *
   * @return <pre>
   * Expected system classloader not available.</pre>
   */
  String getMissingClassloaderErrorText ( final Locale locale )
  {
    return this.getMessage ( "missingClassloaderError", locale );
  }

  /**
   * Gets the message with key {@code "missingClassloaderError"}.
   *
   * @return <pre>
   * Expected system classloader not available.</pre>
   */
  MessageFormat getMissingClassloaderErrorMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "missingClassloaderError", locale ), locale );
  }
  /**
   * Gets the text of the message with key {@code "invalidMultiplicity"}.
   *
   * @return <pre>
   * {0} implementations for specification {1} with multiplicity MULTIPLICITY_ONE.</pre>
   */
  String getInvalidMultiplicityText ( final Locale locale )
  {
    return this.getMessage ( "invalidMultiplicity", locale );
  }

  /**
   * Gets the message with key {@code "invalidMultiplicity"}.
   *
   * @return <pre>
   * {0} implementations for specification {1} with multiplicity MULTIPLICITY_ONE.</pre>
   */
  MessageFormat getInvalidMultiplicityMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "invalidMultiplicity", locale ), locale );
  }
  /**
   * Gets the text of the message with key {@code "noValidationWarning"}.
   *
   * @return <pre>
   * Unsupported or no JAXP runtime environment. {0}</pre>
   */
  String getNoValidationWarningText ( final Locale locale )
  {
    return this.getMessage ( "noValidationWarning", locale );
  }

  /**
   * Gets the message with key {@code "noValidationWarning"}.
   *
   * @return <pre>
   * Unsupported or no JAXP runtime environment. {0}</pre>
   */
  MessageFormat getNoValidationWarningMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "noValidationWarning", locale ), locale );
  }
  /**
   * Gets the text of the message with key {@code "noInterface"}.
   *
   * @return <pre>
   * {0} is not a public interface.</pre>
   */
  String getNoInterfaceText ( final Locale locale )
  {
    return this.getMessage ( "noInterface", locale );
  }

  /**
   * Gets the message with key {@code "noInterface"}.
   *
   * @return <pre>
   * {0} is not a public interface.</pre>
   */
  MessageFormat getNoInterfaceMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "noInterface", locale ), locale );
  }
  /**
   * Gets the text of the message with key {@code "addedPlatformSpecification"}.
   *
   * @return <pre>
   * Added platform specification {0}.</pre>
   */
  String getAddedPlatformSpecificationText ( final Locale locale )
  {
    return this.getMessage ( "addedPlatformSpecification", locale );
  }

  /**
   * Gets the message with key {@code "addedPlatformSpecification"}.
   *
   * @return <pre>
   * Added platform specification {0}.</pre>
   */
  MessageFormat getAddedPlatformSpecificationMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "addedPlatformSpecification", locale ), locale );
  }
  /**
   * Gets the text of the message with key {@code "addedPlatformModule"}.
   *
   * @return <pre>
   * Added platform module {0}.</pre>
   */
  String getAddedPlatformModuleText ( final Locale locale )
  {
    return this.getMessage ( "addedPlatformModule", locale );
  }

  /**
   * Gets the message with key {@code "addedPlatformModule"}.
   *
   * @return <pre>
   * Added platform module {0}.</pre>
   */
  MessageFormat getAddedPlatformModuleMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "addedPlatformModule", locale ), locale );
  }
  /**
   * Gets the text of the message with key {@code "unsupportedMultiplicity"}.
   *
   * @return <pre>
   * Unsupported multiplicity {0}.</pre>
   */
  String getUnsupportedMultiplicityText ( final Locale locale )
  {
    return this.getMessage ( "unsupportedMultiplicity", locale );
  }

  /**
   * Gets the message with key {@code "unsupportedMultiplicity"}.
   *
   * @return <pre>
   * Unsupported multiplicity {0}.</pre>
   */
  MessageFormat getUnsupportedMultiplicityMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "unsupportedMultiplicity", locale ), locale );
  }
  /**
   * Gets the text of the message with key {@code "unsupportedPropertyType"}.
   *
   * @return <pre>
   * Unsupported property type {0}.</pre>
   */
  String getUnsupportedPropertyTypeText ( final Locale locale )
  {
    return this.getMessage ( "unsupportedPropertyType", locale );
  }

  /**
   * Gets the message with key {@code "unsupportedPropertyType"}.
   *
   * @return <pre>
   * Unsupported property type {0}.</pre>
   */
  MessageFormat getUnsupportedPropertyTypeMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "unsupportedPropertyType", locale ), locale );
  }

  /**
   * Gets a message for a given key and locale.
   *
   * @param key the key of the message to return.
   * @param locale the locale of the message.
   *
   * @return message for {@code key} using {@code locale}.
   */
  private String getMessage( final String key, Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return ResourceBundle.getBundle( "org/jdtaus/core/container/ri/client/DefaultModel",
                                     locale ).getString( key );

  }
}
